[edk2-devel] [PATCH v1 03/13] MdePkg: Rename SBSA Generic Watchdog to Arm Generic Watchdog

Chris Jones christopher.jones at arm.com
Fri Jul 30 08:26:39 UTC 2021


Make changes to ACPI 6.4 header according to the latest specification:
- ACPI 6.4 January 2021, Section 5.2.24, Table 5.100 & Section 5.2.24.2
- Mantis ID 2126 (https://mantis.uefi.org/mantis/view.php?id=2126)

Signed-off-by: Chris Jones <christopher.jones at arm.com>
---
 MdePkg/Include/IndustryStandard/Acpi64.h | 14 +++++++-------
 1 file changed, 7 insertions(+), 7 deletions(-)

diff --git a/MdePkg/Include/IndustryStandard/Acpi64.h b/MdePkg/Include/IndustryStandard/Acpi64.h
index 5a0e5b29c7e41cfa03ebc28e306719762b72b76d..9a1339c78e915d451847190ec7000e4961b6cac5 100644
--- a/MdePkg/Include/IndustryStandard/Acpi64.h
+++ b/MdePkg/Include/IndustryStandard/Acpi64.h
@@ -1373,7 +1373,7 @@ typedef struct {
 /// Platform Timer Type
 ///
 #define EFI_ACPI_6_4_GTDT_GT_BLOCK                       0
-#define EFI_ACPI_6_4_GTDT_SBSA_GENERIC_WATCHDOG          1
+#define EFI_ACPI_6_4_GTDT_ARM_GENERIC_WATCHDOG           1
 
 ///
 /// GT Block Structure
@@ -1415,7 +1415,7 @@ typedef struct {
 #define EFI_ACPI_6_4_GTDT_GT_BLOCK_COMMON_FLAG_ALWAYS_ON_CAPABILITY      BIT1
 
 ///
 /// SBSA Generic Watchdog Structure
 ///
 typedef struct {
   UINT8   Type;
@@ -1425,14 +1425,14 @@ typedef struct {
   UINT64  WatchdogControlFramePhysicalAddress;
   UINT32  WatchdogTimerGSIV;
   UINT32  WatchdogTimerFlags;
-} EFI_ACPI_6_4_GTDT_SBSA_GENERIC_WATCHDOG_STRUCTURE;
+} EFI_ACPI_6_4_GTDT_ARM_GENERIC_WATCHDOG_STRUCTURE;
 
 ///
 /// SBSA Generic Watchdog Timer Flags.  All other bits are reserved and must be 0.
 ///
-#define EFI_ACPI_6_4_GTDT_SBSA_GENERIC_WATCHDOG_FLAG_TIMER_INTERRUPT_MODE          BIT0
-#define EFI_ACPI_6_4_GTDT_SBSA_GENERIC_WATCHDOG_FLAG_TIMER_INTERRUPT_POLARITY      BIT1
-#define EFI_ACPI_6_4_GTDT_SBSA_GENERIC_WATCHDOG_FLAG_SECURE_TIMER                  BIT2
+#define EFI_ACPI_6_4_GTDT_ARM_GENERIC_WATCHDOG_FLAG_TIMER_INTERRUPT_MODE          BIT0
+#define EFI_ACPI_6_4_GTDT_ARM_GENERIC_WATCHDOG_FLAG_TIMER_INTERRUPT_POLARITY      BIT1
+#define EFI_ACPI_6_4_GTDT_ARM_GENERIC_WATCHDOG_FLAG_SECURE_TIMER                  BIT2
 
 //
 // NVDIMM Firmware Interface Table definition.
@@ -1415,7 +1415,7 @@ typedef struct {
 
 ///
-/// SBSA Generic Watchdog Structure
+/// Arm Generic Watchdog Structure
 ///
 typedef struct {
@@ -1425,14 +1425,14 @@ typedef struct {
 
 ///
-/// SBSA Generic Watchdog Timer Flags.  All other bits are reserved and must be 0.
+/// Arm Generic Watchdog Timer Flags.  All other bits are reserved and must be 0.
 ///
-- 
Guid("CE165669-3EF3-493F-B85D-6190EE5B9759")



-=-=-=-=-=-=-=-=-=-=-=-
Groups.io Links: You receive all messages sent to this group.
View/Reply Online (#78393): https://edk2.groups.io/g/devel/message/78393
Mute This Topic: https://groups.io/mt/84546292/1813853
Group Owner: devel+owner at edk2.groups.io
Unsubscribe: https://edk2.groups.io/g/devel/unsub [edk2-devel-archive at redhat.com]
-=-=-=-=-=-=-=-=-=-=-=-





More information about the edk2-devel-archive mailing list